import { ɵɵdefineInjectable, Injectable, Component, Input, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { NavigationEnd, PRIMARY_OUTLET, ActivatedRoute, Router, RouterModule } from '@angular/router';
import { filter } from 'rxjs/operators';
import { map } from 'rxjs/internal/operators';
import { CommonModule } from '@angular/common';

class Ng7BootstrapBreadcrumbService {
    constructor() {
        this.breadcrumbLabels = new BehaviorSubject([]);
        this.newBreadcrumb = new BehaviorSubject([]);
    }
    updateBreadcrumbLabels(labels) {
        this.breadcrumbLabels.next(labels);
    }
    updateBreadcrumb(newBreadcrumb) {
        this.newBreadcrumb.next(newBreadcrumb);
    }
}
Ng7BootstrapBreadcrumbService.ɵprov = ɵɵdefineInjectable({ factory: function Ng7BootstrapBreadcrumbService_Factory() { return new Ng7BootstrapBreadcrumbService(); }, token: Ng7BootstrapBreadcrumbService, providedIn: "root" });
Ng7BootstrapBreadcrumbService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
Ng7BootstrapBreadcrumbService.ctorParameters = () => [];

class Ng7BootstrapBreadcrumbComponent {
    constructor(activatedRoute, router, ng7BootstrapBreadcrumbService) {
        this.activatedRoute = activatedRoute;
        this.router = router;
        this.ng7BootstrapBreadcrumbService = ng7BootstrapBreadcrumbService;
        this.breadcrumb = [];
        this.bgColor = '#eee';
        this.fontSize = '18px';
        this.fontColor = '#0275d8';
        this.lastLinkColor = '#000';
        this.symbol = ' / ';
        this.breadCrumbData();
    }
    ngOnInit() {
        this.ng7BootstrapBreadcrumbService.breadcrumbLabels.subscribe((labelData) => {
            for (const label in labelData) {
                if (labelData.hasOwnProperty(label)) {
                    this.breadcrumb.map((crumb) => {
                        const labelParams = crumb.label.match(/[^{{]+(?=\}})/g);
                        if (labelParams) {
                            for (const labelParam of labelParams) {
                                const dynamicData = labelData[label];
                                if (labelParam === label) {
                                    crumb.label = crumb.label.replace('{{' + labelParam + '}}', dynamicData);
                                }
                            }
                        }
                    });
                }
            }
        });
        this.ng7BootstrapBreadcrumbService.newBreadcrumb.subscribe((breadcrumb) => {
            if (breadcrumb.length > 0) {
                this.updateData(this.activatedRoute, breadcrumb);
            }
        });
    }
    breadCrumbData() {
        this.router.events
            .pipe(filter(event => event instanceof NavigationEnd))
            .pipe(map(() => this.activatedRoute))
            .pipe(map((route) => {
            while (route.firstChild) {
                route = route.firstChild;
            }
            return route;
        }))
            .pipe(filter(route => route.outlet === PRIMARY_OUTLET))
            .subscribe(route => {
            this.params = route.snapshot.params;
            this.updateData(route, null);
        });
    }
    updateData(route, newBreadcrumb) {
        if (route.snapshot.data.breadcrumb || newBreadcrumb) {
            const data = route.snapshot.data.breadcrumb ? route.snapshot.data.breadcrumb : newBreadcrumb;
            const breadcrumb = (JSON.parse(JSON.stringify(data)));
            breadcrumb.map((crumb) => {
                const urlChunks = crumb.url.split('/');
                for (const chunk of urlChunks) {
                    if (chunk.includes(':')) {
                        const paramID = chunk.replace(':', '');
                        // const routerParamID = route.snapshot.params[paramID];
                        const routerParamID = this.params[paramID];
                        crumb.url = crumb.url.replace(`:${paramID}`, routerParamID);
                    }
                }
                const labelParams = crumb.label.match(/[^{{]+(?=\}})/g);
                if (labelParams) {
                    for (const labelParam of labelParams) {
                        // const routerParamID = route.snapshot.params[labelParam.trim()];
                        const routerParamID = this.params[labelParam.trim()];
                        if (routerParamID) {
                            crumb.label = crumb.label.replace('{{' + labelParam + '}}', routerParamID);
                        }
                        else {
                            // crumb.label = crumb.label.replace('{{' + labelParam + '}}', '');
                        }
                    }
                }
            });
            this.breadcrumb = breadcrumb;
        }
        else {
            this.breadcrumb = [];
        }
    }
}
Ng7BootstrapBreadcrumbComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line: component-selector
                selector: 'app-ng7-bootstrap-breadcrumb',
                template: "<nav aria-label=\"breadcrumb\" [ngStyle]=\"{'background-color': bgColor}\">\r\n    <ol class=\"breadcrumb\" *ngIf=\"breadcrumb.length\">\r\n        <ng-container *ngFor=\"let item of breadcrumb; let i = index\">\r\n            <li class=\"breadcrumb-item\" [ngClass]=\"{'active': breadcrumb.length !== i+1}\" [ngStyle]=\"{'font-size': fontSize}\">\r\n                <a *ngIf=\"item?.url\" [routerLink]=\"item?.url\"  [ngStyle]=\"{'color': fontColor}\">{{ item.label }}</a>\r\n                <span *ngIf=\"!item?.url\" [ngStyle]=\"{'color': lastLinkColor}\">{{ item.label }}</span>\r\n            </li>\r\n        </ng-container>\r\n    </ol>\r\n</nav>\r\n",
                styles: [""]
            },] }
];
Ng7BootstrapBreadcrumbComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: Router },
    { type: Ng7BootstrapBreadcrumbService }
];
Ng7BootstrapBreadcrumbComponent.propDecorators = {
    bgColor: [{ type: Input }],
    fontSize: [{ type: Input }],
    fontColor: [{ type: Input }],
    lastLinkColor: [{ type: Input }],
    symbol: [{ type: Input }]
};

class Ng7BootstrapBreadcrumbModule {
}
Ng7BootstrapBreadcrumbModule.decorators = [
    { type: NgModule, args: [{
                declarations: [Ng7BootstrapBreadcrumbComponent],
                imports: [
                    RouterModule,
                    CommonModule
                ],
                exports: [Ng7BootstrapBreadcrumbComponent]
            },] }
];

/*
 * Public API Surface of ng7-bootstrap-breadcrumb
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Ng7BootstrapBreadcrumbComponent, Ng7BootstrapBreadcrumbModule, Ng7BootstrapBreadcrumbService };
//# sourceMappingURL=ng7-bootstrap-breadcrumb.js.map
